==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/ProjectListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ProjectListBuilder extends io.fabric8.openshift.api.model.ProjectListFluentImpl<io.fabric8.openshift.api.model.ProjectListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ProjectList,io.fabric8.openshift.api.model.ProjectListBuilder>{
  public ProjectListBuilder() {
    this(false);
  }
  public ProjectListBuilder(java.lang.Boolean validationEnabled) {
    this(new ProjectList(), validationEnabled);
  }
  public ProjectListBuilder(io.fabric8.openshift.api.model.ProjectListFluent<?> fluent) {
    this(fluent, false);
  }
  public ProjectListBuilder(io.fabric8.openshift.api.model.ProjectListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ProjectList(), validationEnabled);
  }
  public ProjectListBuilder(io.fabric8.openshift.api.model.ProjectListFluent<?> fluent,io.fabric8.openshift.api.model.ProjectList instance) {
    this(fluent, instance, false);
  }
  public ProjectListBuilder(io.fabric8.openshift.api.model.ProjectListFluent<?> fluent,io.fabric8.openshift.api.model.ProjectList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProjectListBuilder(io.fabric8.openshift.api.model.ProjectList instance) {
    this(instance,false);
  }
  public ProjectListBuilder(io.fabric8.openshift.api.model.ProjectList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ProjectListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ProjectList build() {
    ProjectList buildable = new ProjectList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProjectListBuilder that = (ProjectListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.3.1-sources.jar: io/fabric8/openshift/api/model/ProjectListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ProjectListBuilder extends ProjectListFluentImpl<ProjectListBuilder> implements VisitableBuilder<ProjectList,ProjectListBuilder>{
  public ProjectListBuilder() {
    this(false);
  }
  public ProjectListBuilder(Boolean validationEnabled) {
    this(new ProjectList(), validationEnabled);
  }
  public ProjectListBuilder(ProjectListFluent<?> fluent) {
    this(fluent, false);
  }
  public ProjectListBuilder(ProjectListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ProjectList(), validationEnabled);
  }
  public ProjectListBuilder(ProjectListFluent<?> fluent,ProjectList instance) {
    this(fluent, instance, false);
  }
  public ProjectListBuilder(ProjectListFluent<?> fluent,ProjectList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProjectListBuilder(ProjectList instance) {
    this(instance,false);
  }
  public ProjectListBuilder(ProjectList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ProjectListFluent<?> fluent;
  Boolean validationEnabled;
  public ProjectList build() {
    ProjectList buildable = new ProjectList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
